@@ -8,8 +8,7 @@ mod status;
 use rusoto_cloudformation::{CloudFormation, CloudFormationClient};
 
 pub use apply::{
-    Apply, ApplyError, ApplyEvent, ApplyInput, ApplyOutput, Capability, Parameter, StackOutput,
-    TemplateSource,
+    Apply, ApplyError, ApplyInput, ApplyOutput, Capability, Parameter, StackOutput, TemplateSource,
 };
 pub use event::{StackEvent, StackEventDetails};
 pub use status::{
